# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .doc_tag_response import DocTagResponse

__all__ = ["DoctagCreateResponse"]

DoctagCreateResponse: TypeAlias = List[DocTagResponse]
