# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .workspace_response import WorkspaceResponse

__all__ = ["UserListWorkspacesResponse"]

UserListWorkspacesResponse: TypeAlias = List[WorkspaceResponse]
